#ifndef _CEGOADMSCREEN_H_INCLUDED_
#define _CEGOADMSCREEN_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoAdmScreen.h  
// ---------------
// Cego admin screen interface definition
//
// Design and Implementation by Bjoern Lemke
//
// (C)opyright 2000-2022 Bjoern Lemke
//
// INTERFACE MODULE
//
// Class: CegoAdmScreen
// 
// Description: Cursor based administration database administration frontend
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

#include <ctype.h>
#include <string.h>

#include <lfcbase/Chain.h>
#include <lfcbase/ListT.h>
#include <lfcbase/Datetime.h>
#include <lfcbase/SigHandler.h>
#include <lfcbase/Screen.h>

#include "CegoAdminHandler.h"

class CegoAdmScreen : public Screen {
    
public:
    
    CegoAdmScreen(CegoAdminHandler *pAH);
    ~CegoAdmScreen();
    
    void showScreen();

private:

    void showPool();

    void showThread();
    void showDBThread();
    void showLastThreadAction(int threadId);	
    void showAdmThread();
    void showLogThread();

    // tableset basic
    void showTableSet();
    void showTableSetInfo(const Chain& tableSet);
    void showTableSetDefineMask();
    void showTableSetEditMask(const Chain& tableSet);
    int showTableSetActionMenu(const Chain& tableSet, const Chain& tsStatus);

    void performTableSetAction(const Chain& tableset, int action);
    
    // tableset datafile
    void showTableSetFileInfo(const Chain& tableSet);
    void showTableSetAddFile(const Chain& tableSet);

    // tableset archlog
    void showTableSetListArchlog(const Chain& tableSet);
    void showTableSetAddArchlog(const Chain& tableSet);
    void showTableSetRemoveArchlog(const Chain& tableSet, const Chain& archId);
    void showTableSetToggleArchlog(const Chain& tableSet, const Chain& archMode);

    // tableset backup
    void showTableSetBackupInfo(const Chain& tableSet);
    void showTableSetBackupAdd(const Chain& tableSet);
    void showTableSetBackupRecovery(const Chain& tableSet, const Chain& buId);

    void showTableSetExport(const Chain& tableSet);
    void showTableSetImport(const Chain& tableSet);
    
    // tableset querycache
    void showTableSetQueryCache(const Chain& tableSet);
    

    void showTableSetHelp();

    // user menu
    void showUser();
    Chain showUserAddMask();
    void showRoleAssignMask(const Chain& userName, const ListT<Chain>& userRoleList);
    void showRoleRemoveMask(const Chain& userName, const ListT<Chain>& userRoleList);
    void showUserChangePwd(const Chain& userName);
    int showUserActionMenu();

    // role menu
    void showRole();
    void showRoleAddMask();
    void showRolePermListMask(const Chain& role);
    void showRolePermSetMask(const Chain& role,
			     const Chain& permId,
			     const Chain& permTS,
			     const Chain& permFilter,
			     const Chain& permRight);

    void showManager();
    void showLogManager();
    void showBackupManager();

    void showRefreshMenu();

    ListT<Chain> roleString2List(const Chain& roleString);
    
    CegoAdminHandler* _pAH;

    int _refInterval;
};

#endif














